<?php

namespace Dollie\Core\Modules\Forms;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

use Dollie\Core\Modules\Backups;
use Dollie\Core\Singleton;

/**
 * Class CreateBackup
 *
 * @package Dollie\Core\Modules\Forms
 */
class CreateBackup extends Singleton {

	/**
	 * @var string
	 */
	private $form_key = 'form_dollie_create_backup';

	/**
	 * CreateBackup constructor.
	 */
	public function __construct() {
		parent::__construct();

		add_action( 'acf/init', [ $this, 'acf_init' ] );
	}

	/**
	 * Init ACF
	 */
	public function acf_init() {
		// Form args
		add_filter( 'af/form/args/key=' . $this->form_key, [ $this, 'change_form_args' ] );

		// Form submission action.
		add_action( 'af/form/before_submission/key=' . $this->form_key, [ $this, 'submission_callback' ], 10, 3 );
	}

	/**
	 * Callback
	 *
	 * @param $form
	 * @param $fields
	 * @param $args
	 */
	public function submission_callback( $form, $fields, $args ) {
		$container_id = (int) $_POST['dollie_post_id'];

		Backups::instance()->make( $container_id );

	}

	/**
	 * Change form args
	 *
	 * @param $args
	 *
	 * @return mixed
	 */
	public function change_form_args( $args ) {
		$args['submit_text'] = __( 'Create New Backup', 'dollie' );

		return $args;
	}


}
